package com.tcctyn.system.api;

import com.tcctyn.common.core.constant.SecurityConstants;
import com.tcctyn.common.core.constant.ServiceNameConstants;
import com.tcctyn.common.core.web.domain.R;
import com.tcctyn.system.api.domain.SysDept;
import com.tcctyn.system.api.domain.SysUser;
import com.tcctyn.system.api.factory.RemoteUserFallbackFactory;
import com.tcctyn.system.api.model.LoginUser;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户服务
 * 
 * @author tcctyn
 */
@FeignClient(contextId = "remoteUserService", value = ServiceNameConstants.SYSTEM_SERVICE, fallbackFactory = RemoteUserFallbackFactory.class)
public interface RemoteUserService
{
    /**
     * 通过用户名查询用户信息
     *
     * @param username 用户名
     * @param source 请求来源
     * @return 结果
     */
    @GetMapping("/system/user/info/{username}")
    public R<LoginUser> getUserInfo(@PathVariable("username") String username, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 注册用户信息
     *
     * @param sysUser 用户信息
     * @param source 请求来源
     * @return 结果
     */
    @PostMapping("/system/user/register")
    public R<Boolean> registerUserInfo(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 记录用户登录IP地址和登录时间
     *
     * @param sysUser 用户信息
     * @param source 请求来源
     * @return 结果
     */
    @PutMapping("/system/user/recordlogin")
    public R<Boolean> recordUserLogin(@RequestBody SysUser sysUser, @RequestHeader(SecurityConstants.FROM_SOURCE) String source);

    /**
     * 通过用户ID查询用户
     *
     * @return 结果
     */
    @PostMapping("/system/user/selectUserById/{userId}")
    public R<SysUser> selectUserById(@PathVariable("userId") Long userId);

    /**
     * 通过条件查询查询用户列表
     *
     * @param sysUser 用户信息
     * @return 结果
     */
    @PostMapping("/system/user/selectUserList")
    public R<List<SysUser>> selectUserList(@RequestBody SysUser sysUser);

    /**
     * 获取用户列表用于前端选择器
     * @param regionId 归属地区id
     * @return
     */
    @GetMapping("/system/user/userNames/{regionId}")
    public  R<List<SysUser>> selectUserByRegionIdList(@PathVariable("regionId")  Long regionId) ;
    /**
     * 通过用户ID查询用户
     *
     * @return 结果
     */
    @PostMapping("/system/dept/selectDeptById/{deptId}")
    public R<SysDept> selectDeptById(@PathVariable("deptId") Long deptId);

    /**
     * 通过条件查询查询用户列表
     *
     * @return 结果
     */
    @PostMapping("/system/dept/selectDeptList")
    public R<List<SysDept>> selectDeptList(@RequestBody SysDept sysDept);

}
