package com.tcctyn.common.core.utils;

/**
 * 距离计算工具类
 */

public class DistanceCalculationUtil {

    // 地球半径（单位：千米）
    private static final double EARTH_RADIUS_KM = 6371.0;

    public static double calculateDistance(String lon1, String lat1, String lon2, String lat2) {
        // 将角度转换为弧度
        double lat1Rad = Math.toRadians(Double.valueOf(lat1));
        double lon1Rad = Math.toRadians(Double.valueOf(lon1));
        double lat2Rad = Math.toRadians(Double.valueOf(lat2));
        double lon2Rad = Math.toRadians(Double.valueOf(lon2));

        // 计算纬度和经度的差值
        double deltaLat = lat2Rad - lat1Rad;
        double deltaLon = lon2Rad - lon1Rad;

        // 应用Haversine公式
        double a = Math.pow(Math.sin(deltaLat / 2), 2)
                + Math.cos(lat1Rad) * Math.cos(lat2Rad)
                * Math.pow(Math.sin(deltaLon / 2), 2);
        double c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1 - a));

        // 计算距离
        return EARTH_RADIUS_KM * c;
    }
}
