package com.tcctyn.common.core.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.io.*;
import java.util.concurrent.TimeUnit;

/**
 * @author songguoqiang
 * @date 2025年04月17日 22:42:13
 */
@Component

public class FFmpegExecutor {

    private Process ffmpegProcess;
    private OutputStream ffmpegInput;
    private static final Logger logger = LoggerFactory.getLogger(FFmpegExecutor.class);


    public void start(String format, String outputUrl, String rtspUrl) throws IOException {
        // 构建 FFmpeg 命令
        ProcessBuilder pb = new ProcessBuilder(
                "ffmpeg",
                "-i", rtspUrl,
                "-c:v", "copy",
                "-c:a", "aac",
                "-ar", "44100",
                "-f", format,
                outputUrl
        );

        // 启动进程
        ffmpegProcess = pb.start();
        ffmpegInput = ffmpegProcess.getOutputStream();

        // 异步读取输出日志
        new Thread(() -> {
            try (BufferedReader reader = new BufferedReader(
                    new InputStreamReader(ffmpegProcess.getInputStream()))) {
                String line;
                while ((line = reader.readLine()) != null) {
                    logger.info("[FFmpeg] {}", line);
                }
            } catch (IOException e) {
                logger.error("Failed to read FFmpeg output: {}", e.getMessage());
            }
        }).start();
    }
    public void writeFrame(byte[] frameData) throws IOException {
        ffmpegInput.write(frameData);
        ffmpegInput.flush();
    }

    public void stop() {
        if (ffmpegProcess != null) {
            try {
                // 1. 尝试优雅退出（发送 'q' 命令）
                if (ffmpegInput != null) {
                    ffmpegInput.write("q\n".getBytes());
                    ffmpegInput.flush();
                }
            } catch (IOException e) {
                logger.warn("Failed to send exit command: {}", e.getMessage());
            }

            // 2. 关闭输入流
            try {
                if (ffmpegInput != null) {
                    ffmpegInput.close();
                }
            } catch (IOException e) {
                logger.error("Error closing input stream: {}", e.getMessage());
            }

            // 3. 销毁进程
            if (ffmpegProcess.isAlive()) {
                ffmpegProcess.destroy();
                try {
                    if (!ffmpegProcess.waitFor(5, TimeUnit.SECONDS)) {
                        ffmpegProcess.destroyForcibly();
                        logger.warn("FFmpeg process was forcibly terminated");
                    }
                } catch (InterruptedException e) {
                    Thread.currentThread().interrupt();
                    logger.error("Interrupted while waiting for termination: {}", e.getMessage());
                }
            }
            ffmpegProcess = null; // 清除引用
        }
    }

    private void readProcessOutput(InputStream inputStream) {
        try (BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream))) {
            String line;
            while ((line = reader.readLine()) != null) {
                System.out.println(line);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}

//package com.tcctyn.common.utils;
//
//import com.tcctyn.common.annotation.Anonymous;
//import org.springframework.stereotype.Component;
//
//import java.io.IOException;
//import java.io.OutputStream;
//import java.nio.ByteBuffer;
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * @author Jason
// * @date 2025年03月26日 22:42:13
// */
//@Component
//
//public class FFmpegExecutor {
//
//    private Process ffmpegProcess;
//    private OutputStream ffmpegInput;
//    public void start(String format, String outputUrl, byte[] sps, byte[] pps) throws IOException {
//        List<String> command = new ArrayList<>();
//        command.add("ffmpeg");
//        command.add("-y");
//        command.add("-f"); command.add("h264");
//        command.add("-i"); command.add("pipe:0");
//        command.add("-c:v"); command.add("copy");  // 直接拷贝视频流
//        command.add("-f"); command.add(format);
//        command.add("-flvflags"); command.add("no_duration_filesize");
//        command.add("-movflags"); command.add("faststart");
//        command.add("-preset"); command.add("ultrafast");
//        command.add("-tune"); command.add("zerolatency");
//        command.add("-g"); command.add("50");  // GOP长度
//        command.add("-keyint_min"); command.add("25");  // 最小关键帧间隔
//        command.add("-x264-params"); command.add("scenecut=0:open_gop=0:min-keyint=25:keyint=50");
//        command.add(outputUrl);
//
//        ProcessBuilder pb = new ProcessBuilder(command);
//        pb.redirectErrorStream(true);
//        ffmpegProcess = pb.start();
//        ffmpegInput = ffmpegProcess.getOutputStream();
//
//        // 写入extradata
//        writeExtradata(sps, pps);
//    }
//
//    public void writeFrame(byte[] frameData) throws IOException {
//        ffmpegInput.write(frameData);
//        ffmpegInput.flush();
//    }
//
//    public void stop() {
//        try {
//            if (ffmpegInput != null) {
//                ffmpegInput.close();
//            }
//            if (ffmpegProcess != null) {
//                ffmpegProcess.destroyForcibly();
//            }
//        } catch (IOException e) {
//            e.printStackTrace();
//        }
//    }
//}