package com.tcctyn.common.core.web.domain.entity;

import com.baomidou.mybatisplus.annotation.*;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 区域信息表
 * </p>
 *
 * @author 代超
 * @since 2024-09-24
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("region_info")
public class RegionInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 父id
     */
    @NotNull(message = "父级id不能为空")
    private Long parentId;

    /**
     * 全路径 父id为0的数据，默认传0
     */
    private String ancestors;

    /**
     * 地区编号
     */
    @NotBlank(message = "地区编号不能为空")
    private String areaNo;

    /**
     * 地区名称
     */
    @NotBlank(message = "地区名称不能为空")
    private String areaName;

    /**
     * 地区类型：林区、林场、电子围栏、切片
     */
    @NotBlank(message = "地区类型不能为空")
    private String areaType;

    /**
     * 植被类型
     */
    private String vegetationType;

    /**
     * 土质类型
     */
    private String soilType;

    /**
     * 地区运营状态
     */
    private String operationStatus;

    /**
     * 地区排序
     */
    private Integer sortNo;

    /**
     * 归属行政区划
     */
    private String administrativeDivision;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 地区负责单位
     */
    private String belongingUnit;

    /**
     * 负责单位联系方式
     */
    private String unitTel;

    /**
     * 地区简介
     */
    private String areaIntroduction;

    /**
     * 地区图片，多张以英文逗号分隔
     */
    private String areaPicture;

    /**
     * 边框颜色
     */
    private String borderColor;

    /**
     * 边框宽度
     */
    private String borderWidth;

    /**
     * 边框透明度
     */
    private String borderTransparency;

    /**
     * 填充色
     */
    private String fillColor;

    /**
     * 填充色透明度
     */
    private String fillColorTransparency;

    /**
     * 边框样式
     */
    private String borderStyle;

    /**
     * 地区面积（平方米）
     */
    private String regionArea;

    /**
     * 经纬度信息
     */
    private String coordinateInfo;

    /**
     * 备注信息
     */
    private String remark;

    /**
     * 该条记录是否被删除，1-已删除，0-未删除
     */
    @TableLogic
    private Integer delFlag;

    /**
     * 创建人员姓名
     */
    private String createdBy;

    /**
     * 记录创建时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.INSERT)
    private Date createdTime;

    /**
     * 修改人员姓名
     */
    private String updatedBy;

    /**
     * 记录修改时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.UPDATE)
    private Date updatedTime;

    /**
     * 子节点列表
     */
    @TableField(exist = false)
    private List<RegionInfo> children = new ArrayList<>();

    @TableField(exist = false)
    private boolean hasChildren;

}
