package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.CarouselImageConfigVO;
import com.tcctyn.iot.forestfire.domain.CarouselImageConfig;
import com.tcctyn.iot.forestfire.searcher.carouselimageconfig.CarouselImageEnableFlagRequest;
import com.tcctyn.iot.forestfire.service.ICarouselImageConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 轮播图配置表 前端控制器
 * </p>
 *
 * @author daichao
 * @since 2024-12-17
 */

@RestController
@RequestMapping("/carouselImageConfig")
public class CarouselImageConfigController extends BaseController {


    @Autowired
    private ICarouselImageConfigService iCarouselImageConfigService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<CarouselImageConfig> pageList = iCarouselImageConfigService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        CarouselImageConfig carouselImageConfig = iCarouselImageConfigService.getById(id);
        CarouselImageConfigVO carouselImageConfigVO = new CarouselImageConfigVO();
        BeanUtils.copyBeanProp(carouselImageConfig, carouselImageConfigVO);
        return AjaxResult.success(carouselImageConfigVO);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody CarouselImageConfig params) {
        Integer result = iCarouselImageConfigService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iCarouselImageConfigService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@Validated @RequestBody CarouselImageConfig params) {
        Integer result = iCarouselImageConfigService.update(params);
        return AjaxResult.success(result);
    }

    /**
     * 分页列表查询
     *
     * @param carouselImageConfig
     * @return
     */
    @GetMapping(value = "/selectList")
    public TableDataInfo selectList(CarouselImageConfig carouselImageConfig) {
        startPage();
        List<CarouselImageConfig> carouselImageConfigList = iCarouselImageConfigService.selectList(carouselImageConfig);
        List<CarouselImageConfigVO> voList = BeanUtils.copyList(carouselImageConfigList, CarouselImageConfigVO.class);
        return getDataTable(carouselImageConfigList, voList);
    }

    /**
     * 轮播图启用/禁用接口
     */
    @PostMapping(value = "/updateEnableFlag")
    public AjaxResult updateEnableFlag(@Validated @RequestBody CarouselImageEnableFlagRequest request) {
        CarouselImageConfig carouselImageConfig = new CarouselImageConfig();
        BeanUtils.copyBeanProp(request, carouselImageConfig);
        Integer result = iCarouselImageConfigService.update(carouselImageConfig);
        return AjaxResult.success(result);
    }

    /**
     * APP端给到前端所有启用状态下的轮播图
     */
    @GetMapping(value = "/selectEnabled")
    public AjaxResult selectEnabled() {
        CarouselImageConfig carouselImageConfig = new CarouselImageConfig();
        carouselImageConfig.setEnableFlag(1);
        List<CarouselImageConfig> carouselImageConfigList = iCarouselImageConfigService.selectList(carouselImageConfig);
        List<CarouselImageConfigVO> voList = BeanUtils.copyList(carouselImageConfigList, CarouselImageConfigVO.class);
        return AjaxResult.success(voList);
    }
}
