package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.*;
import com.tcctyn.iot.forestfire.domain.DeviceInfo;
import com.tcctyn.iot.forestfire.searcher.BaseIdListSearcher;
import com.tcctyn.iot.forestfire.searcher.BaseRegionSearcher;
import com.tcctyn.iot.forestfire.searcher.deviceinfo.DeviceOwnershipSearcher;
import com.tcctyn.iot.forestfire.service.ICommonService;
import com.tcctyn.iot.forestfire.service.IDeviceChanelsService;
import com.tcctyn.iot.forestfire.service.IDeviceConfigService;
import com.tcctyn.iot.forestfire.service.IDeviceInfoService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 设备信息表 前端控制器
 * </p>
 *
 * @author 代超
 * @since 2024-10-09
 */

@RestController
@RequestMapping("/deviceInfo")
public class DeviceInfoController extends BaseController {


    @Autowired
    private IDeviceInfoService iDeviceInfoService;

    @Autowired
    private ICommonService commonService;

    @Autowired
    private IDeviceConfigService deviceConfigService;

    @Autowired
    private IDeviceChanelsService deviceChanelsService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<DeviceInfo> pageList = iDeviceInfoService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        DeviceInfoVO vo = iDeviceInfoService.getById(id);
        vo.setDeviceConfig(deviceConfigService.selectByDeviceNo(vo.getDeviceNo()));
        return AjaxResult.success(vo);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody DeviceInfo params) {
        Integer result = iDeviceInfoService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iDeviceInfoService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@Validated @RequestBody DeviceInfo params) {
        Integer result = iDeviceInfoService.update(params);
        return AjaxResult.success(result);
    }

    /**
     * 分页查询
     *
     * @param deviceInfo
     * @return
     */
    @GetMapping(value = "/selectList")
    public TableDataInfo selectList(@RequestBody DeviceInfo deviceInfo) {
        startPage();
        List<DeviceInfo> list = iDeviceInfoService.selectList(deviceInfo);
        //处理给前端的regionName,pointName,airportName;
        List<DeviceInfoVO> voList = BeanUtils.copyList(list, DeviceInfoVO.class);
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> pointIdAndNameMap = commonService.pointMapIdToName(null);
        Map<Long, String> airportIdAndNameMap = commonService.airportMapIdToName(null);
        for (DeviceInfoVO deviceInfoVO : voList) {
            String forestName = regionIdAndNameMap.get(deviceInfoVO.getForestId()) == null ? "" : regionIdAndNameMap.get(deviceInfoVO.getForestId());
            String farmName = regionIdAndNameMap.get(deviceInfoVO.getFarmId()) == null ? "" : regionIdAndNameMap.get(deviceInfoVO.getFarmId());
            String fenceName = regionIdAndNameMap.get(deviceInfoVO.getFenceId()) == null ? "" : regionIdAndNameMap.get(deviceInfoVO.getFenceId());
            deviceInfoVO.setRegionName(forestName + (StringUtils.isEmpty(farmName) ? "" : "/" + farmName) + (StringUtils.isEmpty(fenceName) ? "" : "/" + fenceName));

            deviceInfoVO.setPointName(pointIdAndNameMap.get(deviceInfoVO.getPointId()) == null ? "" : pointIdAndNameMap.get(deviceInfoVO.getPointId()));
            deviceInfoVO.setAirportName(airportIdAndNameMap.get(deviceInfoVO.getAirportId()) == null ? "" : airportIdAndNameMap.get(deviceInfoVO.getAirportId()));
            deviceInfoVO.setPointOrAirportName(StringUtils.isEmpty(deviceInfoVO.getPointName()) ? deviceInfoVO.getAirportName() : deviceInfoVO.getPointName());

            //如果设备配置信息表中无该设备，则在config返回空
            deviceInfoVO.setDeviceConfig(deviceConfigService.selectByDeviceNo(deviceInfoVO.getDeviceNo()));

            //添加推流地址
            if (deviceInfoVO.getDeviceNo() != null) {
                List<DeviceChanelsVO> deviceChanelsVOList = deviceChanelsService.selectByDeviceNo(deviceInfoVO.getDeviceNo());
                deviceInfoVO.setDeviceChanelsVOList(deviceChanelsVOList);
            }
        }

        return getDataTable(list, voList);
    }

    /**
     * 根据设备编号查询设备信息及归属点位信息
     * 点位信息包括：经纬度，点位类型
     */
    @GetMapping(value = "/selectByDeviceNo/{deviceNo}")
    public AjaxResult selectByDeviceNo(@PathVariable("deviceNo") String deviceNo) {
        DeviceAndPointInfoVO vo = iDeviceInfoService.selectByDeviceNo(deviceNo);
        return AjaxResult.success(vo);
    }

    /**
     * 大屏页面设备统计信息列表
     */

    @GetMapping(value = "/deviceStatistics")
    public AjaxResult deviceStatistics(@RequestBody DeviceInfo deviceInfo) {
        DeviceStatisticsVO vo = iDeviceInfoService.deviceStatistics(deviceInfo);
        return AjaxResult.success(vo);
    }

    /**
     * 设备快捷修改启用/停用状态接口
     */
    @PostMapping(value = "/updateEnableFlag")
    public AjaxResult updateEnableFlag(@RequestBody DeviceInfo params) {
        Integer result = iDeviceInfoService.updateEnableFlag(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/deleteBatch")
    public AjaxResult deleteBatch(@RequestBody BaseIdListSearcher<Long> searcher) {
        Integer result = iDeviceInfoService.deleteBatch(searcher.getIdList());
        return AjaxResult.success(result);
    }

    /**
     * 提供给前端的查询设备归属接口
     *
     * @param searcher
     * @return
     */
    @PostMapping(value = "/queryOwnership")
    public AjaxResult queryOwnership(@RequestBody DeviceOwnershipSearcher searcher) {
        List<DeviceOwnerVO> voList = iDeviceInfoService.queryOwnership(searcher);
        return AjaxResult.success(voList);
    }

    /**
     * 设备列表设备统计接口
     *
     * @return
     */
    @PostMapping(value = "/statisticsByStatus")
    public AjaxResult statisticsByStatus() {
        DeviceStatisticsByStatusVO vo = iDeviceInfoService.statisticsByStatus();
        return AjaxResult.success(vo);
    }

    /**
     * 查询云台/卡口下的设备列表
     */
    @GetMapping(value = "/listByPointId/{pointId}")
    public AjaxResult listByPointId(@PathVariable("pointId") Long pointId) {
        DeviceInfo deviceInfo = new DeviceInfo();
        deviceInfo.setPointId(pointId);
        List<DeviceInfo> list = iDeviceInfoService.selectList(deviceInfo);
        return AjaxResult.success(list);
    }

    /**
     * 大屏页面3 视频监控模块，云台、卡口下的设备统计：设备总数、云台设备数量、卡口设备数量、设备在线率
     */
    @PostMapping(value = "/deviceStatisticsByPoint")
    public AjaxResult deviceStatisticsByPoint(@RequestBody(required = false) BaseRegionSearcher searcher) {
        DeviceStatisticsByPointVO vo = iDeviceInfoService.deviceStatisticsByPoint(searcher);
        return AjaxResult.success(vo);
    }

    /**
     * 大屏页面1，查询机场信息按钮，在页面上可以展示机场的位置、图标、名称
     */
    @GetMapping(value = "/selectAirport")
    public AjaxResult selectAirport(BaseRegionSearcher searcher) {
        List<AirportVO> airportVOList = iDeviceInfoService.selectAirport(searcher);
        return AjaxResult.success(airportVOList);
    }

    /**
     * 根据机场id查询机场下的无人机信息
     *
     * @param airportId
     * @return
     */
    @Deprecated
    @GetMapping(value = "/selectDroneByAirportId/{airportId}")
    public AjaxResult selectDroneByAirportId(@PathVariable("airportId") Long airportId) {
        List<DeviceInfo> deviceInfoList = iDeviceInfoService.selectDroneByAirportId(airportId);
        List<DeviceInfoVO> voList = BeanUtils.copyList(deviceInfoList, DeviceInfoVO.class);
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> airportIdAndNameMap = commonService.airportMapIdToName(null);
        voList.forEach(deviceInfoVO -> {
            deviceInfoVO.setRegionName(regionIdAndNameMap.get(deviceInfoVO.getRegionId()) == null ? "" : regionIdAndNameMap.get(deviceInfoVO.getRegionId()));
            deviceInfoVO.setAirportName(airportIdAndNameMap.get(deviceInfoVO.getAirportId()) == null ? "" : airportIdAndNameMap.get(deviceInfoVO.getAirportId()));
        });
        return AjaxResult.success(voList);
    }

    /**
     * 查询摄像头类型的设备列表，暂时不分页，后面有需求再做分页处理
     */
    @GetMapping(value = "/selectCamera")
    public AjaxResult selectCamera(BaseRegionSearcher searcher) {
        List<CameraVO> cameraVOList = iDeviceInfoService.selectCamera(searcher);
        return AjaxResult.success(cameraVOList);
    }


}
