package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.FireReportStatisticsVO;
import com.tcctyn.iot.forestfire.VO.FireReportVO;
import com.tcctyn.iot.forestfire.domain.FireReport;
import com.tcctyn.iot.forestfire.service.ICommonService;
import com.tcctyn.iot.forestfire.service.IFireReportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 * 火情上报表 前端控制器
 * </p>
 *
 * @author 代超
 * @since 2024-11-01
 */

@RestController
@RequestMapping("/fireReport")
public class FireReportController extends BaseController {


    @Autowired
    private IFireReportService iFireReportService;

    @Autowired
    private ICommonService commonService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<FireReport> pageList = iFireReportService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        FireReport fireReport = iFireReportService.getById(id);
        FireReportVO fireReportVO = new FireReportVO();
        if (Objects.nonNull(fireReport)) {
            BeanUtils.copyBeanProp(fireReport, fireReportVO);
        } else {
            return AjaxResult.success(null);
        }
        //给前端地区名称与处理人姓名
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(fireReportVO.getRegionId());
        Map<Long, String> userIdAndNameMap = commonService.userMapIdToName(fireReportVO.getReporterId());
        fireReportVO.setRegionName(regionIdAndNameMap.get(fireReportVO.getRegionId()));
        fireReportVO.setReporterName(userIdAndNameMap.get(fireReportVO.getReporterId()));
        return AjaxResult.success(fireReportVO);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody FireReport params) {
        //火情上报人
//        params.setReporterId(getUserId());
        Integer result = iFireReportService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iFireReportService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody FireReport params) {
        Integer result = iFireReportService.update(params);
        return AjaxResult.success(result);
    }

    /**
     * 火情上报列表分页查询
     */
    @GetMapping(value = "/selectList")
    public TableDataInfo selectList(FireReport fireReport) {
        startPage();
        List<FireReport> fireReportList = iFireReportService.selectList(fireReport);
        List<FireReportVO> voList = BeanUtils.copyList(fireReportList, FireReportVO.class);
        //给前端地区名称与处理人姓名
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> userIdAndNameMap = commonService.userMapIdToName(null);
        voList.forEach(vo -> {
            vo.setRegionName(regionIdAndNameMap.get(vo.getRegionId()));
            vo.setReporterName(userIdAndNameMap.get(vo.getReporterId()));
        });

        return getDataTable(fireReportList, voList);
    }

    @PostMapping(value = "/archive")
    public AjaxResult archive(@RequestBody FireReport fireReport) {
        Integer result = iFireReportService.archive(fireReport);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/fireReportStatistics")
    public AjaxResult fireReportStatistics() {
        FireReportStatisticsVO vo = iFireReportService.fireReportStatistics();
        return AjaxResult.success(vo);
    }

    /**
     * 火情处理
     *
     * @param fireReport
     * @return
     */
    @PostMapping(value = "/disposal")
    public AjaxResult disposal(@RequestBody FireReport fireReport) {
        Integer result = iFireReportService.disposal(fireReport);
        return AjaxResult.success(result);
    }
}
