package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.*;
import com.tcctyn.iot.forestfire.domain.FireWarningInfo;
import com.tcctyn.iot.forestfire.searcher.BaseIdListSearcher;
import com.tcctyn.iot.forestfire.searcher.BaseTimeSearcher;
import com.tcctyn.iot.forestfire.searcher.firewarning.FireWarningAnalyzeSearcher;
import com.tcctyn.iot.forestfire.searcher.firewarning.FireWarningConditionSearcher;
import com.tcctyn.iot.forestfire.service.ICommonService;
import com.tcctyn.iot.forestfire.service.IFireWarningInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 * 火情预警信息表 前端控制器
 * </p>
 *
 * @author 代超
 * @since 2024-10-08
 */

@RestController
@RequestMapping("/fireWarningInfo")
public class FireWarningInfoController extends BaseController {


    @Autowired
    private IFireWarningInfoService iFireWarningInfoService;

    @Autowired
    private ICommonService commonService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<FireWarningInfo> pageList = iFireWarningInfoService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        FireWarningInfo fireWarningInfo = iFireWarningInfoService.getById(id);
        FireWarningInfoVO fireWarningInfoVO = new FireWarningInfoVO();
        if (Objects.nonNull(fireWarningInfo)) {
            BeanUtils.copyBeanProp(fireWarningInfo, fireWarningInfoVO);
        } else {
            return AjaxResult.success(null);
        }
        //给前端地区名称与处理人名称
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> userIdAndNameMap = commonService.userMapIdToName(null);
        fireWarningInfoVO.setRegionName(regionIdAndNameMap.get(fireWarningInfoVO.getRegionId()));
        fireWarningInfoVO.setDisposalByName(userIdAndNameMap.get(fireWarningInfoVO.getDisposalBy()));
        return AjaxResult.success(fireWarningInfoVO);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody FireWarningInfo params) {
        Integer result = iFireWarningInfoService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iFireWarningInfoService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody FireWarningInfo params) {
        Integer result = iFireWarningInfoService.update(params);
        return AjaxResult.success(result);
    }

    /**
     * 火情预警信息分页查询
     *
     * @param fireWarningInfo
     * @return
     */
    @GetMapping(value = "/selectList")
    public TableDataInfo selectList(FireWarningInfo fireWarningInfo) {
        startPage();
        List<FireWarningInfo> fireWarningInfoList = iFireWarningInfoService.selectList(fireWarningInfo);
        List<FireWarningInfoVO> voList = BeanUtils.copyList(fireWarningInfoList, FireWarningInfoVO.class);
        //给前端地区名称与处理人姓名
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> userIdAndNameMap = commonService.userMapIdToName(null);
        voList.forEach(vo -> {
            vo.setRegionName(regionIdAndNameMap.get(vo.getRegionId()));
            vo.setDisposalByName(userIdAndNameMap.get(vo.getDisposalBy()));
        });

        return getDataTable(fireWarningInfoList, voList);
    }

    /**
     * 根据处置状态统计数量
     *
     * @return
     */
    @PostMapping(value = "/countByDisposalStatus")
    public AjaxResult countByDisposalStatus(@RequestBody(required = false) FireWarningConditionSearcher searcher) {
        FireWarningCountByStatusVO vo = iFireWarningInfoService.countByDisposalStatus(searcher);
        return AjaxResult.success(vo);
    }

    /**
     * 根据火情等级统计数量
     *
     * @return
     */
    @PostMapping(value = "/countByFireLevel")
    public AjaxResult countByFireLevel(@RequestBody(required = false) FireWarningConditionSearcher searcher) {
        List<FireWarningCountByLevelVO> voList = iFireWarningInfoService.countByFireLevel(searcher);
        return AjaxResult.success(voList);
    }

    /**
     * 根据条件查询火情信息，可以选择性带时间条件
     *
     * @return
     */
    @PostMapping(value = "/selectByCondition")
    public AjaxResult selectByCondition(@RequestBody(required = false) FireWarningConditionSearcher searcher) {
        List<FireWarningInfoVO> voList = iFireWarningInfoService.selectByCondition(searcher);
        return AjaxResult.success(voList);
    }

    /**
     * 查询最近的十条火情预警信息，以时间倒序，将未处理的火情信息置顶
     *
     * @return
     */
    @PostMapping(value = "/selectLimit")
    public AjaxResult selectLimit(@RequestBody(required = false) FireWarningConditionSearcher searcher) {
        List<FireWarningInfoVO> voList = iFireWarningInfoService.selectLimit(searcher);
        return AjaxResult.success(voList);
    }

    /**
     * 大屏页面二，按照火情数据来源进行分组统计
     */
    @PostMapping(value = "/statisticsByDataSource")
    public AjaxResult statisticsByDataSource(@RequestBody(required = false) BaseTimeSearcher searcher) {
        FireWarningStatisticsByDataSourceVO vo = iFireWarningInfoService.statisticsByDataSource(searcher);
        return AjaxResult.success(vo);
    }

    /**
     * 火情预警归档
     *
     * @param id
     * @return
     */
    @PostMapping(value = "/archive/{id}")
    public AjaxResult archive(@PathVariable("id") Long id) {
        Integer result = iFireWarningInfoService.archive(id);
        return AjaxResult.success(result);
    }

    /**
     * 火情预警批量归档
     *
     * @param searcher
     * @return
     */
    @PostMapping(value = "/archiveBatch")
    public AjaxResult archiveBatch(@RequestBody BaseIdListSearcher<Long> searcher) {
        Integer result = iFireWarningInfoService.archiveBatch(searcher);
        return AjaxResult.success(result);
    }

    /**
     * APP端火情预警查询已处理的火情预警列表（分页）
     *
     * @param fireWarningInfo
     * @return
     */
    @GetMapping(value = "/selectDisposedList")
    public TableDataInfo selectDisposedList(FireWarningInfo fireWarningInfo) {
        startPage();
        List<FireWarningInfo> fireWarningInfoList = iFireWarningInfoService.selectDisposedList(fireWarningInfo);
        List<FireWarningInfoVO> voList = BeanUtils.copyList(fireWarningInfoList, FireWarningInfoVO.class);
        //给前端地区名称与处理人姓名
        Map<Long, String> regionIdAndNameMap = commonService.regionMapIdToName(null);
        Map<Long, String> userIdAndNameMap = commonService.userMapIdToName(null);
        voList.forEach(vo -> {
            vo.setRegionName(regionIdAndNameMap.get(vo.getRegionId()));
            vo.setDisposalByName(userIdAndNameMap.get(vo.getDisposalBy()));
        });
        return getDataTable(fireWarningInfoList, voList);
    }

    /**
     * 火情预警研判接口
     *
     * @param searcher
     * @return
     */
    @PostMapping(value = "/analyze")
    public AjaxResult analyze(@Validated @RequestBody FireWarningAnalyzeSearcher searcher) {
        Long userId = super.getUserId();
        Integer result = iFireWarningInfoService.analyze(searcher, userId);
        return AjaxResult.success(result);
    }

    /**
     * 提供一个模拟火情预警的接口
     * 模拟云台发现火情预警，然后大屏页面上，预警系统跟监控系统可以进行联动
     * TODO  待后续接入硬件设备后，可删除
     * 暂时使用呼马山云台1 ，设备编号为 BC1733545
     */
    @PostMapping(value = "/simulate")
    public AjaxResult simulate() {
        iFireWarningInfoService.simulate();
        return AjaxResult.success("模拟成功");
    }

    /**
     * 火情预警周边查询接口
     * 查询火情预警附近3公里内的 护林员、水源地、仓库
     * 查询范围做成可以灵活配置的，默认为3公里
     * 前端传火情预警id
     */
    @PostMapping(value = "/surroundingSearch/{id}")
    public AjaxResult surroundingSearch(@PathVariable("id") Long id) {
        FireWarningSurroundingVO vo = iFireWarningInfoService.surroundingSearch(id);
        return AjaxResult.success(vo);
    }

    /**
     * 临时接口，后续看需求进行调整或者删除
     * 火情预警误判接口
     */
    @PostMapping(value = "/misjudge/{id}")
    public AjaxResult misjudge(@PathVariable("id") Long id) {
        Integer result = iFireWarningInfoService.misjudge(id);
        return AjaxResult.success(result);
    }
}
