package com.tcctyn.iot.forestfire.controller;

import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.InventoryVO;
import com.tcctyn.iot.forestfire.domain.Inventory;
import com.tcctyn.iot.forestfire.domain.Warehouse;
import com.tcctyn.iot.forestfire.searcher.material.InventorySearcher;
import com.tcctyn.iot.forestfire.service.IInventoryService;
import com.tcctyn.iot.forestfire.service.IWarehouseService;
import com.tcctyn.system.api.RemoteUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 物资库存 前端控制器
 * </p>
 *
 * @author liuzh
 * @since 2024-10-29
 */

@RestController
@RequestMapping("/inventory")
public class InventoryController extends BaseController {


    @Autowired
    private IInventoryService iInventoryService;

    @Autowired
    private IWarehouseService warehouseService;

    @Resource
    private RemoteUserService remoteUserService;

    @GetMapping(value = "/list")
    public TableDataInfo list(InventorySearcher inventorySearcher) {
        startPage();
        List<Inventory> doList = iInventoryService.list(inventorySearcher);
        List<InventoryVO> voList = BeanUtils.copyList(doList, InventoryVO.class);
        voList.forEach(vo -> {
            Warehouse warehouse = warehouseService.getById(vo.getWarehouseId());
            vo.setRegionId(warehouse.getRegionId());
            vo.setWarehouseName(warehouse.getWarehouseName());
            vo.setUserName(remoteUserService.selectUserById(vo.getUserId()).getData().getNickName());
        });

        return getDataTable(doList, voList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        Inventory inventory = iInventoryService.getById(id);
        return AjaxResult.success(inventory);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody Inventory params) {
        Integer result = iInventoryService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result =  iInventoryService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody Inventory params) {
        Integer result = iInventoryService.update(params);
        return AjaxResult.success(result);
    }
}
