package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.KeyAreaInfoVO;
import com.tcctyn.iot.forestfire.domain.KeyAreaInfo;
import com.tcctyn.iot.forestfire.service.ICommonService;
import com.tcctyn.iot.forestfire.service.IKeyAreaInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * <p>
 * 重点监控区域配置表 前端控制器
 * </p>
 *
 * @author daichao
 * @since 2024-12-17
 */

@RestController
@RequestMapping("/keyAreaInfo")
public class KeyAreaInfoController extends BaseController {


    @Autowired
    private IKeyAreaInfoService iKeyAreaInfoService;

    @Autowired
    private ICommonService commonService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<KeyAreaInfo> pageList = iKeyAreaInfoService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        KeyAreaInfo keyAreaInfo = iKeyAreaInfoService.getById(id);
        KeyAreaInfoVO keyAreaInfoVO = new KeyAreaInfoVO();
        BeanUtils.copyBeanProp(keyAreaInfo, keyAreaInfoVO);
        Map<Long, String> regionIdToNameMap = commonService.regionMapIdToName(keyAreaInfoVO.getRegionId());
        keyAreaInfoVO.setRegionName(regionIdToNameMap.get(keyAreaInfoVO.getRegionId()));
        return AjaxResult.success(keyAreaInfoVO);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody KeyAreaInfo params) {
        Integer result = iKeyAreaInfoService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iKeyAreaInfoService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody KeyAreaInfo params) {
        Integer result = iKeyAreaInfoService.update(params);
        return AjaxResult.success(result);
    }

    /**
     * 分页列表查询
     */
    @GetMapping(value = "/selectList")
    public TableDataInfo selectList(KeyAreaInfo keyAreaInfo) {
        startPage();
        List<KeyAreaInfo> keyAreaInfoList = iKeyAreaInfoService.selectList(keyAreaInfo);
        List<KeyAreaInfoVO> voList = BeanUtils.copyList(keyAreaInfoList, KeyAreaInfoVO.class);
        Map<Long, String> regionIdToNameMap = commonService.regionMapIdToName(null);
        voList.forEach(keyAreaInfoVO -> {
            keyAreaInfoVO.setRegionName(Optional.ofNullable(regionIdToNameMap.get(keyAreaInfoVO.getRegionId())).orElse(""));
        });
        return getDataTable(keyAreaInfoList, voList);
    }

    /**
     * 大屏页面给到前端的所有重点区域
     */
    @GetMapping(value = "/selectAll")
    public AjaxResult selectAll() {
        KeyAreaInfo keyAreaInfo = new KeyAreaInfo();
        List<KeyAreaInfo> keyAreaInfoList = iKeyAreaInfoService.selectList(keyAreaInfo);
        List<KeyAreaInfoVO> voList = BeanUtils.copyList(keyAreaInfoList, KeyAreaInfoVO.class);
        Map<Long, String> regionIdToNameMap = commonService.regionMapIdToName(null);
        voList.forEach(keyAreaInfoVO -> {
            keyAreaInfoVO.setRegionName(Optional.ofNullable(regionIdToNameMap.get(keyAreaInfoVO.getRegionId())).orElse(""));
        });
        // 如果存在时间范围，需要判断是否在时间范围内
        if (keyAreaInfo.getStartTime() != null && keyAreaInfo.getEndTime() != null) {
            voList.removeIf(item -> item.getStartTime().getTime() > System.currentTimeMillis() || item.getEndTime().getTime() < System.currentTimeMillis());
        }
        return AjaxResult.success(voList);
    }
}
