package com.tcctyn.iot.forestfire.controller;

import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.common.core.web.page.TableDataInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.MaterialStatisticsVO;
import com.tcctyn.iot.forestfire.VO.MaterialVO;
import com.tcctyn.iot.forestfire.domain.Material;
import com.tcctyn.iot.forestfire.domain.Warehouse;
import com.tcctyn.iot.forestfire.mapper.WarehouseMapper;
import com.tcctyn.iot.forestfire.searcher.material.MaterialAllocateSearcher;
import com.tcctyn.iot.forestfire.searcher.material.MaterialSearcher;
import com.tcctyn.iot.forestfire.service.IMaterialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 物资信息 前端控制器
 * </p>
 *
 * @author liuzh
 * @since 2024-10-09
 */

@RestController
@RequestMapping("/material")
public class MaterialController extends BaseController {

    @Autowired
    private IMaterialService iMaterialService;

    @Resource
    private WarehouseMapper warehouseMapper;

    @GetMapping(value = "/list")
    public TableDataInfo list(MaterialSearcher materialSearcher) {
        startPage();
        List<Material> doList = iMaterialService.list(materialSearcher);
        List<MaterialVO> voList = BeanUtils.copyList(doList, MaterialVO.class);
        voList.forEach(vo -> {
            Warehouse warehouse = warehouseMapper.selectById(vo.getWarehouseId());
            vo.setWarehouseName(warehouse.getWarehouseName());
            vo.setRegionId(warehouse.getRegionId());
        });
        return getDataTable(doList,voList);
    }

    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        Material material = iMaterialService.getById(id);
        return AjaxResult.success(material);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@Validated @RequestBody Material params) {
        return iMaterialService.create(params);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result =  iMaterialService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody Material params) {
        Integer result = iMaterialService.update(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/inbound")
    public AjaxResult inbound(@Validated @RequestBody MaterialAllocateSearcher params) {
        Integer result = iMaterialService.inbound(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/outbound")
    public AjaxResult outbound(@RequestBody MaterialAllocateSearcher params) {
        Integer result = iMaterialService.outbound(params);
        if (result == -1){
            return AjaxResult.warn("请检查库存");
        }
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/allocate")
    public AjaxResult allocate(@RequestBody MaterialAllocateSearcher params) {
        Integer result = iMaterialService.allocate(params);
        if (result == -1){
            return AjaxResult.warn("请检查库存");
        }
        return AjaxResult.success(result);
    }

    @GetMapping(value = "/statistics/{warehouseId}")
    public AjaxResult getStatisticsByWarehouse(@PathVariable("warehouseId") Long warehouseId) {
        List<MaterialStatisticsVO> result = iMaterialService.getStatisticsByWarehouse(warehouseId);
        return AjaxResult.success(result);
    }
}
