package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.iot.forestfire.domain.Road;
import com.tcctyn.iot.forestfire.domain.RoadInfo;
import com.tcctyn.iot.forestfire.searcher.road.RoadSearcher;
import com.tcctyn.iot.forestfire.service.IRoadInfoService;
import com.tcctyn.iot.forestfire.service.IRoadService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 林间道路信息表 前端控制器
 * </p>
 *
 * @author jason
 * @since 2025-03-11
 */

@RestController
@RequestMapping("/road")
public class RoadController extends BaseController {


    @Autowired
    private IRoadService iRoadService;

    @Autowired
    private IRoadInfoService iRoadInfoService;

    @GetMapping(value = "/list")
    public AjaxResult list(RoadSearcher roadSearcher) {
        if (roadSearcher.getPageNo() == null) {
            roadSearcher.setPageNo(1);
        }
        if (roadSearcher.getPageSize() == null) {
            roadSearcher.setPageSize(10);
        }
        Page<Road> pageList = iRoadService.selectPageList(roadSearcher);
        if(ObjectUtils.isNotEmpty(pageList.getRecords())){
            List<Road> records = pageList.getRecords();

            // 遍历 records 并修改每个 Road 对象
            for (Road road : records) {
                // 对 Road 对象进行修改操作
                List<RoadInfo> infoList=iRoadInfoService.list(new QueryWrapper<RoadInfo>().eq("road_id", road.getId()));
                road.setRoadInfoList(infoList);

            }
            // 将修改后的 records 设置回 Page 对象
            pageList.setRecords(records);

        }
        return AjaxResult.success(pageList);
    }

    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") String id) {
        Road road=iRoadService.getById(id);
        if (road==null) {
            return AjaxResult.warn("暂无数据");
        }
        List<RoadInfo> roadInfoList=iRoadInfoService.list(new QueryWrapper<RoadInfo>().eq("road_id", id));
        road.setRoadInfoList(roadInfoList);
        return AjaxResult.success(road);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody Road vo) {
        Integer result = iRoadService.create(vo);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") String id) {
        Road road=iRoadService.getById(id);
        if (road==null) {
            return AjaxResult.error("数据不存在");
        }
        if(ObjectUtils.isNotEmpty(road.getRoadInfoList())){
            for(RoadInfo roadInfo:road.getRoadInfoList()){
                iRoadInfoService.removeById(roadInfo.getId());
            }
        }
        boolean isDel= iRoadService.removeById(id);
        if(isDel){
            return AjaxResult.success("删除成功");
        }else{
            return AjaxResult.success("删除失败");
        }
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody Road params) {
        Integer result = iRoadService.update(params);
        return AjaxResult.success(result);
    }
}
