package com.tcctyn.iot.forestfire.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.controller.BaseController;
import com.tcctyn.common.core.web.domain.AjaxResult;
import com.tcctyn.iot.forestfire.domain.RoadInfo;
import com.tcctyn.iot.forestfire.service.IRoadInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 林间道路详细信息表 前端控制器
 * </p>
 *
 * @author jason
 * @since 2025-03-11
 */

@RestController
@RequestMapping("/roadInfo")
public class RoadInfoController extends BaseController {


    @Autowired
    private IRoadInfoService iRoadInfoService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer pageNo, @RequestParam(required = false) Integer pageSize) {
        if (pageNo == null) {
            pageNo = 1;
        }
        if (pageSize == null) {
            pageSize = 10;
        }
        Page<RoadInfo> pageData = iRoadInfoService.page(new Page<>(pageSize, pageSize));
        return AjaxResult.success(pageData);
    }

    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") String id) {
        RoadInfo roadInfo=iRoadInfoService.getById(id);
        if (roadInfo==null) {
            return AjaxResult.warn("暂无数据");
        }
        return AjaxResult.success(iRoadInfoService.getById(id));
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody RoadInfo roadInfo) {
        Integer result = iRoadInfoService.create(roadInfo);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") String id) {
        RoadInfo roadInfo=iRoadInfoService.getById(id);
        if (roadInfo==null) {
            return AjaxResult.error("数据不存在");
        }
        boolean remove=iRoadInfoService.removeById(id);
        if(remove){
            return AjaxResult.success("删除成功");
        }else{
            return AjaxResult.error("删除失败");
        }
    }

    @PostMapping(value = "/update")
    public AjaxResult delete(@RequestBody RoadInfo params) {
        boolean update= iRoadInfoService.updateById(params);
        if(update) {
            return AjaxResult.success("更新成功");
        }else{
            return AjaxResult.error("更新失败");
        }
    }
}
