package com.tcctyn.iot.forestfire.domain;

import com.baomidou.mybatisplus.annotation.*;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 火情预警信息表
 * </p>
 *
 * @author 代超
 * @since 2024-10-08
 */
@Data
@TableName("fire_warning_info")
public class FireWarningInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 发现火情设备编号
     */
    private String deviceNo;

    /**
     * 设备类型
     */
    private String deviceType;

    /**
     * 地址
     */
    @NotBlank(message = "请输入火情地址")
    private String address;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 纬度
     */
    private String latitude;

    /**
     * 高度
     */
    private String height;

    /**
     * 所属区域id
     */
    @NotNull(message = "请选择所属区域")
    private Long regionId;

    /**
     * 林区id
     */
    private Long forestId;

    /**
     * 林场id
     */
    private Long farmId;

    /**
     * 电子围栏id
     */
    private Long fenceId;

    /**
     * 火情标题
     */
    @NotBlank(message = "请输入火情标题")
    private String fireTitle;

    /**
     * 火情级别
     */
    private String fireLevel;

    /**
     * 起火原因
     */
    private String fireCause;

    /**
     * 处置状态：未处理、已研判、已上报、已归档
     */
    private String disposalStatus;

    /**
     * 研判结果说明
     */
    private String analyzeInstruction;

    /**
     * 处置人
     */
    private Long disposalBy;

    /**
     * 处置时间
     */
    private Date disposalTime;

    /**
     * 失火面积
     */
    private String fireArea;

    /**
     * 损失金额
     */
    private String amountDamage;

    /**
     * 火情图片
     */
    private String firePicture;

    /**
     * 火情预警数据来源
     */
    private String dataSource;

    /**
     * 备注信息
     */
    private String remark;

    /**
     * 误判标识，0-非误判，1-误判，默认是0
     */
    private Integer misjudgeFlag;

    /**
     * 该条记录是否被删除，1-已删除，0-未删除
     */
    @TableLogic
    private Integer delFlag;

    /**
     * 创建人员姓名
     */
    private String createdBy;

    /**
     * 记录创建时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.INSERT)
    private Date createdTime;

    /**
     * 修改人员姓名
     */
    private String updatedBy;

    /**
     * 记录修改时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.UPDATE)
    private Date updatedTime;

}
