package com.tcctyn.iot.forestfire.domain;

import com.baomidou.mybatisplus.annotation.*;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 点位信息表
 * </p>
 *
 * @author 代超
 * @since 2024-09-24
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("point_info")
public class PointInfo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 点位编号
     */
    private String pointNo;

    /**
     * 点位名称
     */
    @NotBlank(message = "资源点名称不能为空")
    private String pointName;

    /**
     * 行政区划
     */
    private String administrativeDivision;

    /**
     * 归属地区id / 归属路径id
     */
    @NotNull(message = "请选择资源点归属林区/林场")
    private Long belongingRegionId;

    /**
     * 林区id
     */
    private Long forestId;

    /**
     * 林场id
     */
    private Long farmId;

    /**
     * 电子围栏id
     */
    private Long fenceId;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 纬度
     */
    private String latitude;

    /**
     * 高度
     */
    private String height;

    /**
     * 点位类型：云台、卡口、打卡点、巡护点
     */
    private String pointType;

    /**
     * 点位顺序
     */
    private Integer sortNo;

    /**
     * 打卡半径，单位：米
     */
    private String checkInRadius;

    /**
     * 点位描述信息
     */
    private String pointDescription;

    /**
     * 设备启用状态：0-停用/1-启用
     */
    private Integer enableFlag;//sgq2025.3.20

    /**
     * 点位图片，多张以英文逗号分隔
     */
    private String pointPicture;

    /**
     * 备注信息
     */
    private String remark;

    /**
     * 该条记录是否被删除，1-已删除，0-未删除
     */
    @TableLogic
    private Integer delFlag;

    /**
     * 创建人员姓名
     */
    private String createdBy;

    /**
     * 记录创建时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.INSERT)
    private Date createdTime;

    /**
     * 修改人员姓名
     */
    private String updatedBy;

    /**
     * 记录修改时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.UPDATE)
    private Date updatedTime;

    /**
     * 点位类型列表，考虑到云台、卡口需要放到一起，作为前端传参
     */
    @TableField(exist = false)
    private List<String> pointTypeList;

}
