package com.tcctyn.iot.forestfire.domain;

import com.baomidou.mybatisplus.annotation.*;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 临时任务表
 * </p>
 *
 * @author 代超
 * @since 2024-11-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("temporary_task")
public class TemporaryTask implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键id
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 任务名称
     */
    @NotBlank(message = "请填写任务名称")
    private String taskName;

    /**
     * 任务类型，火情勘测、物资运输、火情救援、其他，数据字典
     */
    @NotBlank(message = "请选择任务类型")
    private String taskType;

    /**
     * 任务紧急度：一般、重要、紧急， 枚举
     */
    @NotBlank(message = "请选择任务紧急度")
    private String taskUrgency;

    /**
     * 归属区域id
     */
    @NotNull(message = "所属区域不能为空")
    private Long regionId;

    /**
     * 林区id
     */
    private Long forestId;

    /**
     * 林场id
     */
    private Long farmId;

    /**
     * 电子围栏id
     */
    private Long fenceId;

    /**
     * 任务人
     */
    private Long taskPersonId;

    /**
     * 任务下发人id
     */
    private Long issuerId;

    /**
     * 任务下发时间
     */
    private Date issueTime;

    /**
     * 任务内容
     */
    @NotBlank(message = "请填写任务内容")
    private String taskContent;

    /**
     * 任务状态，未接受，执行中，已完成
     */
    private String taskStatus;

    /**
     * 任务接受人
     */
    private Long taskRecipientId;


    /**
     * 任务接受时间
     */
    private Date acceptTime;

    /**
     * 任务完成时间
     */
    private Date completeTime;

    /**
     * 任务归档情况：1-已归档，0-未归档
     */
    private Integer archiveStatus;

    /**
     * 任务归档时间
     */
    private Date archiveTime;

    /**
     * 备注信息
     */
    private String remark;

    /**
     * 该条记录是否被删除，1-已删除，0-未删除
     */
    @TableLogic
    private Integer delFlag;

    /**
     * 创建人员姓名
     */
    private String createdBy;

    /**
     * 记录创建时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.INSERT)
    private Date createdTime;

    /**
     * 修改人员姓名
     */
    private String updatedBy;

    /**
     * 记录修改时间，默认用服务器时间
     */
    @TableField(fill = FieldFill.UPDATE)
    private Date updatedTime;

}
