package com.tcctyn.iot.forestfire.enums;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * 地区分类枚举
 */
public enum AreaTypeEnum {

    /**
     * 林区
     */
    FOREST_DISTRICT("林区"),

    /**
     * 林场
     */
    FOREST_FARM("林场"),

    /**
     * 电子围栏
     */
    ELECTRONIC_FENCE("电子围栏"),

    /**
     * 切片
     */
    SECTION("切片");


    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    /**
     * 描述
     */
    private String desc;

    AreaTypeEnum(String desc) {
        this.desc = desc;
    }

    /**
     * 根据枚举名称获取枚举
     *
     * @param enumName
     * @return
     */
    public static AreaTypeEnum getByEnumName(final String enumName) {
        for (AreaTypeEnum element : values()) {
            if (element.name().equals(enumName)) {
                return element;
            }
        }
        return FOREST_DISTRICT;
    }

    /**
     * 获取枚举名称和desc所有的映射
     *
     * @return
     */
    public static Map<String, String> getName2DescMap() {

        final Map<String, String> name2TitleMap = new LinkedHashMap<>();

        for (AreaTypeEnum element : values()) {
            name2TitleMap.put(element.name(), element.desc);
        }

        return name2TitleMap;
    }
}
