package com.tcctyn.iot.forestfire.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.iot.forestfire.VO.*;
import com.tcctyn.iot.forestfire.domain.DeviceInfo;
import com.tcctyn.iot.forestfire.searcher.BaseRegionSearcher;
import com.tcctyn.iot.forestfire.searcher.deviceinfo.DeviceOwnershipSearcher;

import java.util.List;

/**
 * <p>
 * 设备信息表 服务类
 * </p>
 *
 * @author 代超
 * @since 2024-10-09
 */
public interface IDeviceInfoService  {

    /**
     * <p>
     * 分页列表查询
     * </p>
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    Page<DeviceInfo> list(Integer pageNo, Integer pageSize);

    /**
     * <p>
     * 详情接口
     * </p>
     *
     * @param id
     * @return
     */
    DeviceInfoVO getById(Long id);

    /**
     * <p>
     * 新增接口
     * </p>
     *
     * @param deviceInfo
     * @return
     */
    Integer create(DeviceInfo deviceInfo);


    /**
     * <p>
     * 删除接口
     * </p>
     *
     * @param id
     * @return
     */
    Integer delete(Long id);

    /**
     * <p>
     * 更新接口
     * </p>
     *
     * @param deviceInfo
     * @return
     */
    Integer update(DeviceInfo deviceInfo);

    /**
     * 列表查询
     *
     * @param deviceInfo
     * @return
     */
    List<DeviceInfo> selectList(DeviceInfo deviceInfo);

    /**
     * 根据设备编号查询设备信息
     *
     * @param deviceNo
     * @return
     */
    DeviceAndPointInfoVO selectByDeviceNo(String deviceNo);

    /**
     * 大屏设备信息统计
     *
     * @return
     */
    DeviceStatisticsVO deviceStatistics(DeviceInfo deviceInfo);

    /**
     * 设备快捷修改启用/停用状态接口
     *
     * @param deviceInfo
     * @return
     */
    Integer updateEnableFlag(DeviceInfo deviceInfo);

    /**
     * 设备批量删除接口
     *
     * @param idList
     * @return
     */
    Integer deleteBatch(List<Long> idList);

    /**
     * 根据前端传的设备类型，查询不同的设备归属信息
     *
     * @param searcher
     * @return
     */
    List<DeviceOwnerVO> queryOwnership(DeviceOwnershipSearcher searcher);

    /**
     * 设备列表设备统计接口
     *
     * @return
     */
    DeviceStatisticsByStatusVO statisticsByStatus();

    /**
     * 云台、卡口下的设备统计：设备总数、云台设备数量、卡口设备数量、设备在线率
     *
     * @param searcher
     * @return
     */
    DeviceStatisticsByPointVO deviceStatisticsByPoint(BaseRegionSearcher searcher);

    /**
     * 大屏页面查询机场信息，前端按钮展示机场信息
     *
     * @param searcher
     * @return
     */
    List<AirportVO> selectAirport(BaseRegionSearcher searcher);

    /**
     * 根据机场id查询机场下的无人机信息
     *
     * @param airportId
     * @return
     */
    List<DeviceInfo> selectDroneByAirportId(Long airportId);

    /**
     * 根据点位信息查询点位下的设备信息，传入List<Long>
     *
     * @param pointIdList
     * @return
     */
    List<DeviceInfo> selectListByPointList(List<Long> pointIdList);

    /**
     * 查询摄像头类型的设备列表
     * @param searcher
     * @return
     */
    List<CameraVO> selectCamera(BaseRegionSearcher searcher);
}
