package com.tcctyn.iot.forestfire.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.iot.forestfire.VO.PointAndDeviceInfoVO;
import com.tcctyn.iot.forestfire.VO.PointInfoVO;
import com.tcctyn.iot.forestfire.VO.PointStatisticsByPointTypeVO;
import com.tcctyn.iot.forestfire.domain.PointInfo;

import java.util.List;


/**
 * <p>
 * 点位信息表 服务类
 * </p>
 *
 * @author 代超
 * @since 2024-09-24
 */
public interface IPointInfoService {

    /**
     * <p>
     * 分页列表查询
     * </p>
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    Page<PointInfo> list(Integer pageNo, Integer pageSize);

    /**
     * <p>
     * 详情接口
     * </p>
     *
     * @param id
     * @return
     */
    PointInfoVO getById(Long id);

    /**
     * <p>
     * 新增接口
     * </p>
     *
     * @param pointInfo
     * @return
     */
    Integer create(PointInfo pointInfo);


    /**
     * <p>
     * 删除接口
     * </p>
     *
     * @param id
     * @return
     */
    Integer delete(Long id);

    /**
     * <p>
     * 更新接口
     * </p>
     *
     * @param pointInfo
     * @return
     */
    Integer update(PointInfo pointInfo);

    /**
     * 点位查询接口（不分页）
     *
     * @param pointInfo
     * @return
     */
    List<PointInfo> selectAll(PointInfo pointInfo);

    /**
     * 批量删除接口
     *
     * @param idList
     * @return
     */
    Integer deleteBatch(List<Long> idList);

    /**
     * 列表查询接口
     *
     * @param pointInfo
     * @return
     */
    List<PointInfo> selectList(PointInfo pointInfo);

    /**
     * 设备快捷修改启用/停用状态接口
     *
     * @param pointInfo
     * @return
     */
    Integer updateEnableFlag(PointInfo pointInfo);//sgq2025.3.20

    /**
     * 大屏页面查询监测点信息：云台、卡口
     *
     * @param pointInfo
     * @return
     */
    List<PointAndDeviceInfoVO> queryMonitoringPoint(PointInfo pointInfo);

    /**
     * 资源点分类统计
     * @return
     */
    PointStatisticsByPointTypeVO statisticsByPointType();
}
