package com.tcctyn.iot.forestfire.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.common.core.web.domain.TreeSelect;
import com.tcctyn.common.core.web.domain.entity.RegionInfo;

import java.util.List;


/**
 * <p>
 * 区域信息表 服务类
 * </p>
 *
 * @author 代超
 * @since 2024-09-24
 */
public interface IRegionInfoService {

    /**
     * <p>
     * 分页列表查询
     * </p>
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    Page<RegionInfo> list(Integer pageNo, Integer pageSize);

    /**
     * <p>
     * 详情接口
     * </p>
     *
     * @param id
     * @return
     */
    RegionInfo getById(Long id);

    /**
     * <p>
     * 新增接口
     * </p>
     *
     * @param regionInfo
     * @return
     */
    Integer create(RegionInfo regionInfo);


    /**
     * <p>
     * 删除接口
     * </p>
     *
     * @param id
     * @return
     */
    Integer delete(Long id);

    /**
     * <p>
     * 更新接口
     * </p>
     *
     * @param regionInfo
     * @return
     */
    Integer update(RegionInfo regionInfo);

    /**
     * 林区分页查询接口
     *
     * @param regionInfo
     * @return
     */
    List<RegionInfo> selectList(RegionInfo regionInfo);

    /**
     * 根据父级id查询全部地区
     *
     * @param parentId
     * @return
     */
    List<RegionInfo> selectAllByParentId(Long parentId);

    /**
     * 查询全部的地区树结构信息
     *
     * @return
     */
    List<RegionInfo> selectAll(Integer level);

    /**
     * 根据地区类型查询全部
     *
     * @param areaType
     * @return
     */
    List<RegionInfo> selectAllByAreaType(String areaType);

    /**
     * 查询地区树结构信息
     *
     * @param regionInfo
     * @return
     */
    List<TreeSelect> selectRegionTree(RegionInfo regionInfo);


    /**
     * 查询所有的地区信息
     *
     * @param regionInfo
     * @return
     */
    public List<RegionInfo> selectRegionList(RegionInfo regionInfo);

    /**
     * 构建区域下拉树结构
     *
     * @param regionInfoList 区域列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildRegionTreeSelect(List<RegionInfo> regionInfoList);


    /**
     * 构建前端所需要树结构
     *
     * @param regionInfoList 区域列表
     * @return 树结构列表
     */
    public List<RegionInfo> buildRegionTree(List<RegionInfo> regionInfoList);
}
