package com.tcctyn.iot.forestfire.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.tcctyn.iot.forestfire.VO.*;
import com.tcctyn.iot.forestfire.VO.*;
import com.tcctyn.iot.forestfire.domain.Schedules;
import com.tcctyn.iot.forestfire.searcher.schedules.ScheduleSwapSearcher;
import com.tcctyn.iot.forestfire.searcher.schedules.SchedulesSearcher;

import java.time.YearMonth;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 排班表 服务类
 * </p>
 *
 * @author liuzh
 * @since 2024-09-24
 */
public interface ISchedulesService extends IService<Schedules> {

    /**
    * <p>
    * 查询一周的排班信息
    * </p>
    * @param schedules
    * @return
    */
    List<ScheduleDetail> weekList(Schedules schedules);

    /**
     * <p>
     * 从周排班信息中提取出每条路线的排班信息
     * </p>
     * @param weeklist
     * @return
     */
    List<Map<String,Object>> list(List<ScheduleDetail> weeklist, Schedules schedules);

    /**
     * 生成排班信息
     * @return
     */
    boolean generate();

    /**
    * <p>
    * 详情接口
    * </p>
    * @param id
    * @return
    */
    Schedules getById(Long id);

    /**
    * <p>
    * 新增接口
    * </p>
    * @param schedules
    * @return
    */
    Integer create(Schedules schedules);


    /**
    * <p>
    * 删除接口
    * </p>
    * @param id
    * @return
    */
    Integer delete(Long id);

    /**
    * <p>
    * 更新接口
    * </p>
    * @param schedules
    * @return
    */
    Integer update(Schedules schedules);

    /**
     * 批量操作
     * @param scheduleDetail
     * @return
     */
    Integer createBatch(ScheduleDetail scheduleDetail);

    /**
     * 大屏页面根据林区、林场查询护林员信息
     * @param params
     * @return
     */
    List<RangerInfoVO> queryRangerInfo(SchedulesSearcher params);

    /**
     * 分页查询列表
     * @param schedules
     * @return
     */
    List<Schedules> selectList(Schedules schedules, Date startDate, Date endDate, String userName);

    /**
     * 调整排班
     *
     * @param scheduleSwapSearcher
     * @return
     */
    Integer swapSchedule(ScheduleSwapSearcher scheduleSwapSearcher);

    /**
     * 统计护林员以及巡护点位信息
     *
     * @param params
     * @return
     */
    RangerStatisticsVO queryRangerStatistics(SchedulesSearcher params);

    /**
     * 大屏页面，查询当日排班信息
     * @param params
     * @return
     */
    List<ScheduleVO> queryScheduleByCondition(SchedulesSearcher params);

    /**
     * 大屏页面根据 scheduleId查询详情
     * @param scheduleId
     * @return
     */
    ScheduleDetailInfoVO queryScheduleDetail(Long scheduleId);

    /**
     * 大屏页面根据林区查询护林员统计信息
     * @param regionId
     * @return
     */
    ForesterStatisticsVO queryForesterStatistics(Long regionId);

    /**
     * 大屏页面根据林区查询护林员值班状态
     * @param regionId
     * @param queryDate
     * @return
     */
    List<UserScheduleStatusVO> getUserScheduleStatus(Long regionId,Date queryDate);

    /**
     * APP端用户登录后获取排班信息
     * @param userId
     * @param date
     * @return
     */
    ScheduleVO getUserSchedule(Long userId,Date date);

    /**
     * APP端查询某人某月的排班打卡情况
     * @param userId
     * @param month
     * @return
     */
    List<SchedulesMonthVO> queryMonthSchedule(Long userId, YearMonth month);

}
