package com.tcctyn.iot.forestfire.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctyn.iot.forestfire.VO.TemporaryTaskVO;
import com.tcctyn.iot.forestfire.domain.TemporaryTask;
import com.tcctyn.iot.forestfire.searcher.BaseIdListSearcher;
import com.tcctyn.iot.forestfire.searcher.temporarytask.TemporaryTaskStatusSearcher;

import java.util.List;


/**
 * <p>
 * 临时任务表 服务类
 * </p>
 *
 * @author 代超
 * @since 2024-11-01
 */
public interface ITemporaryTaskService {

    /**
     * <p>
     * 分页列表查询
     * </p>
     *
     * @param pageNo
     * @param pageSize
     * @return
     */
    Page<TemporaryTask> list(Integer pageNo, Integer pageSize);

    /**
     * <p>
     * 详情接口
     * </p>
     *
     * @param id
     * @return
     */
    TemporaryTask getById(Long id);

    /**
     * <p>
     * 新增接口
     * </p>
     *
     * @param temporaryTask
     * @return
     */
    Integer create(TemporaryTask temporaryTask);


    /**
     * <p>
     * 删除接口
     * </p>
     *
     * @param id
     * @return
     */
    Integer delete(Long id);

    /**
     * <p>
     * 更新接口
     * </p>
     *
     * @param temporaryTask
     * @return
     */
    Integer update(TemporaryTask temporaryTask);

    /**
     * 临时任务归档
     *
     * @param id
     * @return
     */
    Integer archive(Long id);

    /**
     * 临时任务批量归档
     *
     * @param searcher
     * @return
     */
    Integer archiveBatch(BaseIdListSearcher<Long> searcher);

    /**
     * 临时任务分页列表查询
     *
     * @param temporaryTask
     * @return
     */
    List<TemporaryTask> selectList(TemporaryTask temporaryTask);

    /**
     * 查一天的临时任务列表
     *
     * @param temporaryTask
     * @return
     */
    List<TemporaryTaskVO> selectOneDayList(TemporaryTask temporaryTask);

    /**
     * 查询未完成、进行中的临时任务（分页）
     *
     * @param temporaryTask
     * @return
     */
    List<TemporaryTask> selectUncompletedList(TemporaryTask temporaryTask);

    /**
     * 任务接受与完成接口
     *
     * @param searcher
     * @param userId
     * @return
     */
    Integer updateTaskStatus(TemporaryTaskStatusSearcher searcher,Long userId);
}
