package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.tcctyn.iot.forestfire.VO.AggregationStatisticsVO;
import com.tcctyn.iot.forestfire.domain.ApprovalRecord;
import com.tcctyn.iot.forestfire.domain.FireReport;
import com.tcctyn.iot.forestfire.domain.FireWarningInfo;
import com.tcctyn.iot.forestfire.domain.TemporaryTask;
import com.tcctyn.iot.forestfire.enums.FireWarningDisposalStatusEnum;
import com.tcctyn.iot.forestfire.enums.TaskStatusEnum;
import com.tcctyn.iot.forestfire.mapper.ApprovalRecordMapper;
import com.tcctyn.iot.forestfire.mapper.FireReportMapper;
import com.tcctyn.iot.forestfire.mapper.FireWarningInfoMapper;
import com.tcctyn.iot.forestfire.mapper.TemporaryTaskMapper;
import com.tcctyn.iot.forestfire.searcher.aggregation.AggregationStatisticsSearcher;
import com.tcctyn.iot.forestfire.service.IAggregationService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 聚合服务实现类
 */
@Service
public class AggregationServiceImpl implements IAggregationService {

    @Resource
    private FireWarningInfoMapper fireWarningInfoMapper;

    @Resource
    private FireReportMapper fireReportMapper;

    @Resource
    private TemporaryTaskMapper temporaryTaskMapper;

    @Resource
    private ApprovalRecordMapper approvalRecordMapper;

    @Override
    public AggregationStatisticsVO statistics(AggregationStatisticsSearcher searcher, Long userId) {

        //未处理的火情预警数
        Long unhandledFireWarningNum = fireWarningInfoMapper.selectCount(new QueryWrapper<FireWarningInfo>().lambda()
                .eq(Objects.nonNull(searcher.getRegionId()), FireWarningInfo::getRegionId, searcher.getRegionId())
                .eq(FireWarningInfo::getDisposalStatus, FireWarningDisposalStatusEnum.UNHANDLED.name())
        );

        //未处理的火情上报数
        Long unhandledFireReportNum = fireReportMapper.selectCount(new QueryWrapper<FireReport>().lambda()
                .eq(Objects.nonNull(searcher.getRegionId()), FireReport::getRegionId, searcher.getRegionId())
                .eq(FireReport::getDisposalStatus, 0)
        );

        //我未接受的任务数
        Long unacceptedTaskNum = temporaryTaskMapper.selectCount(new QueryWrapper<TemporaryTask>().lambda()
                .eq(Objects.nonNull(userId), TemporaryTask::getTaskPersonId, userId)
                .eq(TemporaryTask::getTaskStatus, TaskStatusEnum.NOT_ACCEPTED.name())
        );

        //未处理的审批任务数
        Long unapprovedNum = approvalRecordMapper.selectCount(new QueryWrapper<ApprovalRecord>().lambda()
                .eq(ApprovalRecord::getApprovalFlag, 0)
        );

        //林区下未接受的任务数
        Long unacceptedTaskNumByRegion = temporaryTaskMapper.selectCount(new QueryWrapper<TemporaryTask>().lambda()
                .eq(Objects.nonNull(searcher.getRegionId()), TemporaryTask::getRegionId, searcher.getRegionId())
                .eq(TemporaryTask::getTaskStatus, TaskStatusEnum.NOT_ACCEPTED.name())
        );
        AggregationStatisticsVO vo = new AggregationStatisticsVO();
        vo.setUnhandledFireWarningNum(unhandledFireWarningNum);
        vo.setUnhandledFireReportNum(unhandledFireReportNum);
        vo.setUnacceptedTaskNum(unacceptedTaskNum);
        vo.setUnapprovedNum(unapprovedNum);
        vo.setUnacceptedTaskNumByRegion(unacceptedTaskNumByRegion);
        return vo;
    }

}
