package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctyn.iot.forestfire.domain.ApprovalRecord;
import com.tcctyn.iot.forestfire.domain.LeaveRecord;
import com.tcctyn.iot.forestfire.mapper.ApprovalRecordMapper;
import com.tcctyn.iot.forestfire.mapper.LeaveRecordMapper;
import com.tcctyn.iot.forestfire.searcher.approvalrecord.ApprovalRecordRejectRequest;
import com.tcctyn.iot.forestfire.service.IApprovalRecordService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 审批记录表 服务实现类
 * </p>
 *
 * @author daichao
 * @since 2024-12-09
 */
@Service
public class ApprovalRecordServiceImpl extends ServiceImpl<ApprovalRecordMapper, ApprovalRecord> implements IApprovalRecordService {


    @Resource
    private ApprovalRecordMapper approvalRecordMapper;

    @Resource
    private LeaveRecordMapper leaveRecordMapper;

    @Override
    public Page<ApprovalRecord> list(Integer pageNo, Integer pageSize) {
        return approvalRecordMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public ApprovalRecord getById(Long id) {
        ApprovalRecord approvalRecord = approvalRecordMapper.selectById(id);
        return approvalRecord;
    }

    @Override
    public Integer create(ApprovalRecord approvalRecord) {
        return approvalRecordMapper.insert(approvalRecord);
    }

    @Override
    public Integer delete(Long id) {
        return approvalRecordMapper.deleteById(id);
    }

    @Override
    public Integer update(ApprovalRecord approvalRecord) {
        return approvalRecordMapper.updateById(approvalRecord);
    }

    @Override
    public List<ApprovalRecord> selectList(ApprovalRecord approvalRecord) {
        List<ApprovalRecord> approvalRecordList = approvalRecordMapper.selectList(new QueryWrapper<ApprovalRecord>().lambda()
                .eq(StringUtils.isNotBlank(approvalRecord.getBusinessType()), ApprovalRecord::getBusinessType, approvalRecord.getBusinessType())
                .orderByAsc(ApprovalRecord::getApprovalFlag)
                .orderByDesc(ApprovalRecord::getCreatedTime)
        );
        return approvalRecordList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Integer approved(Long id, Long userId) {
        ApprovalRecord approvalRecord = approvalRecordMapper.selectById(id);
        ApprovalRecord updateDO = new ApprovalRecord();
        updateDO.setId(id);
        updateDO.setApprovalFlag(1);
        updateDO.setApprovalStatus(1);
        updateDO.setReviewerId(userId);
        updateDO.setReviewTime(new Date());
        Integer result = approvalRecordMapper.updateById(updateDO);
        //审批通过后需要同步更新请假记录信息 ,需要判断业务类型，对不同的业务表数据做同步处理
        switch (approvalRecord.getBusinessType()) {
            case "LEAVE":
                LeaveRecord leaveRecord = new LeaveRecord();
                leaveRecord.setId(approvalRecord.getBusinessDataId());
                leaveRecord.setApprovalFlag(1);
                leaveRecord.setApprovalStatus(1);
                leaveRecord.setReviewerId(userId);
                leaveRecord.setReviewTime(new Date());
                leaveRecordMapper.updateById(leaveRecord);
                break;
            default:
                break;
        }
        return result;
    }

    @Override
    public Integer reject(ApprovalRecordRejectRequest request, Long userId) {
        ApprovalRecord approvalRecord = approvalRecordMapper.selectById(request.getId());
        ApprovalRecord updateDO = new ApprovalRecord();
        updateDO.setId(request.getId());
        updateDO.setApprovalFlag(1);
        updateDO.setApprovalStatus(0);
        updateDO.setRejectionStatement(request.getRejectionStatement());
        updateDO.setReviewerId(userId);
        updateDO.setReviewTime(new Date());
        Integer result = approvalRecordMapper.updateById(updateDO);
        switch (approvalRecord.getBusinessType()) {
            case "LEAVE":
                LeaveRecord leaveRecord = new LeaveRecord();
                leaveRecord.setId(approvalRecord.getBusinessDataId());
                leaveRecord.setApprovalFlag(1);
                leaveRecord.setApprovalStatus(0);
                leaveRecord.setRejectionStatement(request.getRejectionStatement());
                leaveRecord.setReviewerId(userId);
                leaveRecord.setReviewTime(new Date());
                leaveRecordMapper.updateById(leaveRecord);
                break;
            default:
                break;
        }
        return result;
    }

}
