package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.tcctyn.common.core.web.domain.R;
import com.tcctyn.common.core.web.domain.entity.RegionInfo;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.BO.SysUserBO;
import com.tcctyn.iot.forestfire.domain.DeviceInfo;
import com.tcctyn.iot.forestfire.domain.PatrolPath;
import com.tcctyn.iot.forestfire.domain.PointInfo;
import com.tcctyn.iot.forestfire.enums.DeviceTypeEnum;
import com.tcctyn.iot.forestfire.enums.PointTypeEnum;
import com.tcctyn.iot.forestfire.mapper.DeviceInfoMapper;
import com.tcctyn.iot.forestfire.mapper.PatrolPathMapper;
import com.tcctyn.iot.forestfire.mapper.PointInfoMapper;
import com.tcctyn.iot.forestfire.mapper.RegionInfoMapper;
import com.tcctyn.iot.forestfire.service.ICommonService;
import com.tcctyn.system.api.RemoteUserService;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.*;

/**
 * 通用接口实现类
 */
@Service
public class CommonServiceImpl implements ICommonService {

    @Resource
    private RegionInfoMapper regionInfoMapper;

    @Resource
    private RemoteUserService remoteUserService;

    @Resource
    private PatrolPathMapper patrolPathMapper;

    @Resource
    private PointInfoMapper pointInfoMapper;

    @Resource
    private DeviceInfoMapper deviceInfoMapper;


    @Override
    public Map<Long, String> regionMapIdToName(Long regionId) {
        Map<Long, String> regionIdAndNameMap = new HashMap<>();
        if (Objects.nonNull(regionId)) {
            RegionInfo regionInfo = regionInfoMapper.selectById(regionId);
            if (Objects.nonNull(regionInfo)) {
                regionIdAndNameMap.put(regionInfo.getId(), regionInfo.getAreaName());
            }
        } else {
            List<RegionInfo> regionInfoList = regionInfoMapper.selectList(new QueryWrapper<>());
            if (!CollectionUtils.isEmpty(regionInfoList)) {
                for (RegionInfo regionInfo : regionInfoList) {
                    regionIdAndNameMap.put(regionInfo.getId(), regionInfo.getAreaName());
                }
            }
        }
        return regionIdAndNameMap;
    }

    @Override
    public Map<Long, String> userMapIdToName(Long userId) {
        Map<Long, String> userIdAndNameMap = new HashMap<>();
        if (Objects.nonNull(userId)) {
            R<com.tcctyn.system.api.domain.SysUser> data = remoteUserService.selectUserById(userId);
            com.tcctyn.system.api.domain.SysUser sysUser = data.getData();
            if (Objects.nonNull(sysUser)) {
                userIdAndNameMap.put(sysUser.getUserId(), sysUser.getNickName());
            }
        } else {

            com.tcctyn.system.api.domain.SysUser sysUser = new com.tcctyn.system.api.domain.SysUser();
            sysUser.setDelFlag("0");
            R<List<com.tcctyn.system.api.domain.SysUser>> listR = remoteUserService.selectUserList(sysUser);
            List<com.tcctyn.system.api.domain.SysUser> sysUserList = listR.getData();
            if (!CollectionUtils.isEmpty(sysUserList)) {
                for (com.tcctyn.system.api.domain.SysUser user : sysUserList) {
                    user.setUserName(user.getNickName());
                }
            }
        }
        return userIdAndNameMap;
    }

    @Override
    public Map<Long, String> pathMapIdToName(Long pathId) {
        Map<Long, String> pathIdAndNameMap = new HashMap<>();
        if (Objects.nonNull(pathId)) {
            PatrolPath patrolPath = patrolPathMapper.selectById(pathId);
            if (Objects.nonNull(patrolPath)) {
                pathIdAndNameMap.put(patrolPath.getId(), patrolPath.getPathName());
            }
        } else {
            List<PatrolPath> patrolPathList = patrolPathMapper.selectList(new QueryWrapper<>());
            if (!CollectionUtils.isEmpty(patrolPathList)) {
                for (PatrolPath patrolPath : patrolPathList) {
                    pathIdAndNameMap.put(patrolPath.getId(), patrolPath.getPathName());
                }
            }
        }
        return pathIdAndNameMap;
    }

    @Override
    public Map<Long, String> pointMapIdToName(Long pointId) {

        Map<Long, String> pointIdAndNameMap = new HashMap<>();
        if (Objects.nonNull(pointId)) {
            PointInfo pointInfo = pointInfoMapper.selectById(pointId);
            if (Objects.nonNull(pointInfo)) {
                pointIdAndNameMap.put(pointInfo.getId(), pointInfo.getPointName());
            }
        } else {
            List<PointInfo> pointInfoList = pointInfoMapper.selectList(new QueryWrapper<PointInfo>().lambda()
                    .in(PointInfo::getPointType, Arrays.asList(PointTypeEnum.PTZ.name(), PointTypeEnum.BAYONET.name(), PointTypeEnum.WATER_SOURCE.name()))
            );
            if (!CollectionUtils.isEmpty(pointInfoList)) {
                for (PointInfo pointInfo : pointInfoList) {
                    pointIdAndNameMap.put(pointInfo.getId(), pointInfo.getPointName());
                }
            }
        }
        return pointIdAndNameMap;
    }

    @Override
    public Map<Long, String> airportMapIdToName(Long airportId) {
        Map<Long, String> airportIdAndNameMap = new HashMap<>();
        if (Objects.nonNull(airportId)) {
            DeviceInfo deviceInfo = deviceInfoMapper.selectById(airportId);
            if (Objects.nonNull(deviceInfo)) {
                airportIdAndNameMap.put(deviceInfo.getId(), deviceInfo.getDeviceName());
            }
        } else {
            List<DeviceInfo> deviceInfoList = deviceInfoMapper.selectList(new QueryWrapper<DeviceInfo>().lambda()
                    .eq(DeviceInfo::getDeviceType, DeviceTypeEnum.AIRPORT.name())
            );
            if (!CollectionUtils.isEmpty(deviceInfoList)) {
                for (DeviceInfo deviceInfo : deviceInfoList) {
                    airportIdAndNameMap.put(deviceInfo.getId(), deviceInfo.getDeviceName());
                }
            }
        }
        return airportIdAndNameMap;
    }

    @Override
    public Map<Long, String> deptMapIdToName(Long deptId) {
        Map<Long, String> deptMapIdToNameMap = new HashMap<>();
        if (Objects.nonNull(deptId)) {
            R<com.tcctyn.system.api.domain.SysDept> data = remoteUserService.selectDeptById(deptId);
            com.tcctyn.system.api.domain.SysDept sysDept = data.getData();
            if (Objects.nonNull(sysDept)) {
                deptMapIdToNameMap.put(sysDept.getDeptId(), sysDept.getDeptName());
            }
        } else {
            com.tcctyn.system.api.domain.SysDept sysDept1 = new com.tcctyn.system.api.domain.SysDept();
            sysDept1.setDelFlag("0");
            R<List<com.tcctyn.system.api.domain.SysDept>> listR = remoteUserService.selectDeptList(sysDept1);
            List<com.tcctyn.system.api.domain.SysDept> sysDeptList = listR.getData();
            if(!CollectionUtils.isEmpty(sysDeptList)){
               for (com.tcctyn.system.api.domain.SysDept sysDept : sysDeptList) {
                   deptMapIdToNameMap.put(sysDept.getDeptId(), sysDept.getDeptName());
               }
           }
        }
        return deptMapIdToNameMap;
    }

    @Override
    public Map<Long, SysUserBO> userMapIdToBO(Long userId) {
        Map<Long, SysUserBO> userIdAndBOMap = new HashMap<>();
        if (Objects.nonNull(userId)) {
            R<com.tcctyn.system.api.domain.SysUser> data = remoteUserService.selectUserById(userId);
            com.tcctyn.system.api.domain.SysUser sysUser = data.getData();
            if (Objects.nonNull(sysUser)) {
                SysUserBO sysUserBO = new SysUserBO();
                BeanUtils.copyBeanProp(sysUser, sysUserBO);
                userIdAndBOMap.put(sysUser.getUserId(), sysUserBO);
            }
        } else {
            com.tcctyn.system.api.domain.SysUser sysUser1 = new com.tcctyn.system.api.domain.SysUser();
            sysUser1.setDelFlag("0");
            R<List<com.tcctyn.system.api.domain.SysUser>> listR = remoteUserService.selectUserList(sysUser1);
            List<com.tcctyn.system.api.domain.SysUser> sysUserList = listR.getData();
            if (!CollectionUtils.isEmpty(sysUserList)) {
                for (com.tcctyn.system.api.domain.SysUser sysUser : sysUserList) {
                    SysUserBO sysUserBO = new SysUserBO();
                    BeanUtils.copyBeanProp(sysUser, sysUserBO);
                    userIdAndBOMap.put(sysUser.getUserId(), sysUserBO);
                }
            }
        }
        return userIdAndBOMap;
    }

}
