package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctyn.common.core.exception.ServiceException;
import com.tcctyn.common.core.utils.FFmpegExecutor;
import com.tcctyn.common.core.utils.bean.BeanUtils;
import com.tcctyn.iot.forestfire.VO.DeviceChanelsVO;
import com.tcctyn.iot.forestfire.domain.DeviceChanels;
import com.tcctyn.iot.forestfire.domain.DeviceConfig;
import com.tcctyn.iot.forestfire.mapper.DeviceChanelsMapper;
import com.tcctyn.iot.forestfire.mapper.DeviceConfigMapper;
import com.tcctyn.iot.forestfire.service.IDeviceChanelsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;

/**
 * <p>
 * 设备通道表 服务实现类
 * </p>
 *
 * @author 宋国强
 * @since 2025-04-09
 */
@Service
public class DeviceChanelsServiceImpl extends ServiceImpl<DeviceChanelsMapper, DeviceChanels> implements IDeviceChanelsService {

    @Resource
    private DeviceChanelsMapper deviceChanelsMapper;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private DeviceConfigMapper deviceConfigMapper;

    @Autowired
    private static final Logger logger = LoggerFactory.getLogger(DeviceChanelsServiceImpl.class);

    // 存储不同设备通道的 FFmpeg 执行器
    private final ConcurrentHashMap<String, FFmpegExecutor> ffmpegExecutorMap = new ConcurrentHashMap<>();
    @Autowired
    private DeviceConfigServicelmpl deviceConfigServicelmpl;

    @Override
    public DeviceChanelsVO getById(Long id) {
        DeviceChanels deviceChanels = deviceChanelsMapper.selectById(id);
        if (deviceChanels == null) {
            throw new ServiceException("设备通道不存在");
        }
        DeviceChanelsVO deviceChanelsVO = new DeviceChanelsVO();
        BeanUtils.copyProperties(deviceChanels, deviceChanelsVO);
        return deviceChanelsVO;
    }

    @Override
    public Integer create(DeviceChanels deviceChanels) {
        int result = deviceChanelsMapper.insert(deviceChanels);
        if (result <= 0) {
            throw new ServiceException("创建设备通道失败");
        }
        return result;
    }

    @Override
    public Integer delete(Long id) {
        int result = deviceChanelsMapper.deleteById(id);
        if (result <= 0) {
            throw new ServiceException("删除设备通道失败");
        }
        return result;
    }

    @Override
    public Integer update(DeviceChanels deviceChanels) {
        int result = deviceChanelsMapper.updateById(deviceChanels);
        if (result <= 0) {
            throw new ServiceException("更新设备通道失败");
        }
        return result;
    }

    @Override
    public List<DeviceChanelsVO> selectByDeviceNo(String deviceNo) {
        List<DeviceChanelsVO> list = deviceChanelsMapper.selectByDeviceNo(deviceNo);
        if (list == null){
            throw new ServiceException("设备通道不存在");
        }
      return list;
    }

    @Override
    public DeviceChanelsVO getStreamUrl(String deviceNo, String chanelNo) {
        DeviceChanelsVO vo= deviceChanelsMapper.getStreamUrl(deviceNo, chanelNo);
        return vo;
    }


    @Override
    public DeviceChanelsVO startPreview(String deviceNo, String chanelNo) {
        logger.info("startPreview called with deviceNo: {}, chanelNo: {}", deviceNo, chanelNo);
        //如果配置异常不存在抛出异常
        DeviceConfig test = deviceConfigServicelmpl.selectByDeviceNo(deviceNo);
        if (test.getUsername() == null) {
            throw new ServiceException("设备配置异常");
        }
        if (test.getPassword() == null) {
            throw new ServiceException("设备配置异常");
        }
        if (test.getIp() == null) {
            throw new ServiceException("设备配置异常");
        }
        if (test.getPort() == null) {
            throw new ServiceException("设备配置异常");
        }

        String redisKey = "preview:" + deviceNo + ":" + chanelNo;

        // 获取 RTMP 地址和 RTSP 流地址
        String rtmpUrl = "rtmp://47.109.202.121:8188/live/" + deviceNo + chanelNo;
        DeviceConfig deviceConfig = deviceConfigServicelmpl.selectByDeviceNo(deviceNo);
        String rtspUrl = String.format("rtsp://%s:%s@%s:%s/Streaming/Channels/%s",
                deviceConfig.getUsername(),
                deviceConfig.getPassword(),
                deviceConfig.getIp(),
                deviceConfig.getPort(),
                chanelNo);
//        String rtspUrl = "D:\\work\\test1.mp4";
        // 原子递增用户计数
        Long userCount = redisTemplate.opsForValue().increment(redisKey);
        if (userCount == null) {
            userCount = 1L;
            redisTemplate.opsForValue().set(redisKey, userCount.toString());
        }

        // 查询设备通道信息
        DeviceChanelsVO deviceChanels = deviceChanelsMapper.getStreamUrl(deviceNo, chanelNo);
        if (deviceChanels == null) {
            logger.error("Device channel not found");
            throw new ServiceException("设备通道不存在");
        }

        // 返回对象
        DeviceChanelsVO vo = new DeviceChanelsVO();
        BeanUtils.copyProperties(deviceChanels, vo);

        // 首次使用时启动 FFmpeg
        if (userCount <= 1) {
            String executorKey = deviceNo + ":" + chanelNo;
            FFmpegExecutor executor = new FFmpegExecutor();
            ffmpegExecutorMap.put(executorKey, executor);

            try {
                logger.info("Starting FFmpeg for {}", executorKey);
                executor.start("flv", rtmpUrl, rtspUrl);
            } catch (IOException e) {
                ffmpegExecutorMap.remove(executorKey); // 启动失败时清理
                redisTemplate.delete(redisKey);        // 重置 Redis 计数
                throw new ServiceException("开启预览失败");
            }  
        }

        return vo;
    }

    @Override
    public String stopPreview(String deviceNo, String chanelNo) {
        logger.info("stopPreview called with deviceNo: {}, chanelNo: {}", deviceNo, chanelNo);
        String redisKey = "preview:" + deviceNo + ":" + chanelNo;

        // 原子递减用户计数
        Long userCount = redisTemplate.opsForValue().decrement(redisKey);
        if (userCount == null || userCount < 0) {
            userCount = 0L;
            redisTemplate.opsForValue().set(redisKey, userCount.toString());
        }

        // 无用户使用时停止 FFmpeg
        if (userCount == 0) {
            String executorKey = deviceNo + ":" + chanelNo;
            FFmpegExecutor executor = ffmpegExecutorMap.remove(executorKey);
            if (executor != null) {
                logger.info("Stopping FFmpeg for {}", executorKey);
                executor.stop();
            }
            redisTemplate.delete(redisKey); // 清理 Redis 键
        }

        return userCount == 0 ? "==ALL stop==" : "==stop==";
    }
}
