package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctyn.common.core.exception.ServiceException;
import com.tcctyn.iot.forestfire.domain.DeviceConfig;
import com.tcctyn.iot.forestfire.mapper.DeviceConfigMapper;
import com.tcctyn.iot.forestfire.service.IDeviceConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
/**
 * <p>
 * 设备配置表 服务实现类
 * </p>
 *
 * @author 宋国强
 * @since 2025-04-14
 */
@Service
public class DeviceConfigServicelmpl extends ServiceImpl<DeviceConfigMapper, DeviceConfig> implements IDeviceConfigService {

    @Resource
    private DeviceConfigMapper deviceConfigMapper;

    @Autowired
    private static final Logger logger = LoggerFactory.getLogger(DeviceChanelsServiceImpl.class);
    @Override
    public DeviceConfig getById(Long id) {
        DeviceConfig deviceConfig = deviceConfigMapper.selectById(id);
        if (deviceConfig == null) {
            throw new ServiceException("设备配置不存在");
        }
        return deviceConfig;
    }

    @Override
    public Integer create(DeviceConfig deviceConfig) {
        //如果已经存在相同编号的设备，返回已经有此设备了
        DeviceConfig existingDeviceConfig = deviceConfigMapper.selectByDeviceNo(deviceConfig.getDeviceNo());
        if (existingDeviceConfig != null) {
            throw new ServiceException("设备配置已存在");
        }

        int result = deviceConfigMapper.insert(deviceConfig);
        if (result <= 0) {
            throw new ServiceException("创建设备配置失败");
        }
        return result;
    }

    @Override
    public Integer delete(Long id) {
        int result = deviceConfigMapper.deleteById(id);
        if (result <= 0) {
            throw new ServiceException("删除设备配置失败");
        }
        return result;
    }

    @Override
    public Integer update(DeviceConfig deviceConfig) {
        int result = deviceConfigMapper.updateById(deviceConfig);
        if (result <= 0) {
            throw new ServiceException("更新设备配置失败");
        }
        return result;
    }

    @Override
    public DeviceConfig selectByDeviceNo(String deviceNo) {

        DeviceConfig deviceConfig = deviceConfigMapper.selectByDeviceNo(deviceNo);
        if (deviceConfig == null) {
            //给前端提示没有对应的设备配置
            throw new ServiceException("设备配置不存在");
        }
        return deviceConfig;
    }

}
