package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctyn.iot.forestfire.domain.Inventory;
import com.tcctyn.iot.forestfire.domain.Warehouse;
import com.tcctyn.iot.forestfire.mapper.InventoryMapper;
import com.tcctyn.iot.forestfire.mapper.WarehouseMapper;
import com.tcctyn.iot.forestfire.searcher.material.InventorySearcher;
import com.tcctyn.iot.forestfire.service.IInventoryService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
* <p>
* 物资库存 服务实现类
* </p>
*
* @author liuzh
* @since 2024-10-29
*/
@Service
public class InventoryServiceImpl extends ServiceImpl<InventoryMapper,Inventory> implements IInventoryService {


    @Resource
    private InventoryMapper inventoryMapper;

    @Resource
    private WarehouseMapper warehouseMapper;

    @Override
    public List<Inventory> list(InventorySearcher inventorySearcher) {
        // 如果林场id和仓库id都传了，则查询该仓库的库存
        if (Objects.nonNull(inventorySearcher.getRegionId()) && Objects.nonNull(inventorySearcher.getWarehouseId())) {
            return inventoryMapper.selectList(new QueryWrapper<Inventory>().lambda()
                    .eq(Inventory::getWarehouseId, inventorySearcher.getWarehouseId())
                    .orderByDesc(Inventory::getCreatedTime));
        }
        // 如果只传了林场id，则查询该林场所有仓库的库存
        if (Objects.isNull(inventorySearcher.getWarehouseId()) && Objects.nonNull(inventorySearcher.getRegionId())){
            List<Warehouse> warehouseList = warehouseMapper.selectList(new QueryWrapper<Warehouse>().eq("region_id", inventorySearcher.getRegionId()));
            // 从 warehouseList 中获取仓库ID
            List<Long> warehouseIdList = warehouseList.stream().map(Warehouse::getWarehouseId).distinct().collect(Collectors.toList());
            return inventoryMapper.selectList(new QueryWrapper<Inventory>().lambda()
                    .in(Inventory::getWarehouseId, warehouseIdList)
                    .orderByDesc(Inventory::getCreatedTime));
        }

        if (Objects.nonNull(inventorySearcher.getWarehouseId())) {
            return new ArrayList<Inventory>();
        }

        return inventoryMapper.selectList(new QueryWrapper<Inventory>().orderByDesc("created_time"));
    }

    @Override
    public Inventory getById(Long id) {
        Inventory inventory = inventoryMapper.selectById(id);
        return inventory;
    }

    @Override
    public Integer create(Inventory inventory) {
        return inventoryMapper.insert(inventory);
    }

    @Override
    public Integer delete(Long id) {
        return inventoryMapper.deleteById(id);
    }

    @Override
    public Integer update(Inventory inventory) {
        return inventoryMapper.updateById(inventory);
    }

}
