package com.tcctyn.iot.forestfire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctyn.common.core.constant.RegionConstants;

import com.tcctyn.common.core.web.domain.entity.RegionInfo;
import com.tcctyn.iot.forestfire.domain.KeyAreaInfo;
import com.tcctyn.iot.forestfire.mapper.KeyAreaInfoMapper;
import com.tcctyn.iot.forestfire.mapper.RegionInfoMapper;
import com.tcctyn.iot.forestfire.service.IKeyAreaInfoService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 重点监控区域配置表 服务实现类
 * </p>
 *
 * @author daichao
 * @since 2024-12-17
 */
@Service
public class KeyAreaInfoServiceImpl extends ServiceImpl<KeyAreaInfoMapper, KeyAreaInfo> implements IKeyAreaInfoService {


    @Resource
    private KeyAreaInfoMapper keyAreaInfoMapper;

    @Resource
    private RegionInfoMapper regionInfoMapper;

    @Override
    public Page<KeyAreaInfo> list(Integer pageNo, Integer pageSize) {
        return keyAreaInfoMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }

    @Override
    public KeyAreaInfo getById(Long id) {
        KeyAreaInfo keyAreaInfo = keyAreaInfoMapper.selectById(id);
        return keyAreaInfo;
    }

    @Override
    public Integer create(KeyAreaInfo keyAreaInfo) {
        //根据归属区域id来查询全路径id , 然后拆分为 forest_id、farm_id、fence_id
        Long regionId = keyAreaInfo.getRegionId();
        if (Objects.nonNull(regionId)) {
            RegionInfo regionInfo = regionInfoMapper.selectById(regionId);
            String ancestors = regionInfo.getAncestors();
            String[] ancestorsArr = ancestors.split(RegionConstants.DIVISION_COMMA);
            switch (ancestorsArr.length) {
                case 1:
                    keyAreaInfo.setForestId(regionId);
                    break;
                case 2:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(regionId);
                    break;
                case 3:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(Long.valueOf(ancestorsArr[2]));
                    keyAreaInfo.setFenceId(regionId);
                    break;
                case 4:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(Long.valueOf(ancestorsArr[2]));
                    keyAreaInfo.setFenceId(Long.valueOf(ancestorsArr[3]));
                    break;
            }
        }
        return keyAreaInfoMapper.insert(keyAreaInfo);
    }

    @Override
    public Integer delete(Long id) {
        return keyAreaInfoMapper.deleteById(id);
    }

    @Override
    public Integer update(KeyAreaInfo keyAreaInfo) {
        //如果修改归属区域的话，需要同步修改forest_id、farm_id、fence_id
        KeyAreaInfo originalKeyAreaInfo = keyAreaInfoMapper.selectById(keyAreaInfo.getId());
        if (!Objects.equals(originalKeyAreaInfo.getRegionId(), keyAreaInfo.getRegionId())) {
            Long regionId = keyAreaInfo.getRegionId();
            RegionInfo regionInfo = regionInfoMapper.selectById(regionId);
            String ancestors = regionInfo.getAncestors();
            String[] ancestorsArr = ancestors.split(RegionConstants.DIVISION_COMMA);
            switch (ancestorsArr.length) {
                case 1:
                    keyAreaInfo.setForestId(regionId);
                    break;
                case 2:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(regionId);
                    break;
                case 3:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(Long.valueOf(ancestorsArr[2]));
                    keyAreaInfo.setFenceId(regionId);
                    break;
                case 4:
                    keyAreaInfo.setForestId(Long.valueOf(ancestorsArr[1]));
                    keyAreaInfo.setFarmId(Long.valueOf(ancestorsArr[2]));
                    keyAreaInfo.setFenceId(Long.valueOf(ancestorsArr[3]));
                    break;
            }
        }
        return keyAreaInfoMapper.updateById(keyAreaInfo);
    }

    @Override
    public List<KeyAreaInfo> selectList(KeyAreaInfo keyAreaInfo) {
        List<KeyAreaInfo> keyAreaInfoList = keyAreaInfoMapper.selectList(new QueryWrapper<KeyAreaInfo>().lambda()
                .eq(Objects.nonNull(keyAreaInfo.getRegionId()), KeyAreaInfo::getRegionId, keyAreaInfo.getRegionId())
                .eq(StringUtils.isNotBlank(keyAreaInfo.getKeyAreaType()), KeyAreaInfo::getKeyAreaType, keyAreaInfo.getKeyAreaType())
                .orderByDesc(KeyAreaInfo::getCreatedTime)
        );
        return keyAreaInfoList;
    }

}
